<?xml version="1.0" ?><!DOCTYPE TS><TS language="hi_IN" version="2.1">
<context>
    <name>DAboutDialog</name>
    <message>
        <location filename="../widgets/daboutdialog.cpp" line="190"/>
        <source>Acknowledgements</source>
        <translation>आभार</translation>
    </message>
    <message>
        <location filename="../widgets/dapplication.cpp" line="1238"/>
        <source>Version: %1</source>
        <translation>संस्करण : %1</translation>
    </message>
    <message>
        <location filename="../widgets/dapplication.cpp" line="1242"/>
        <source>%1 is released under %2</source>
        <translation>%1, %2 के अंतर्गत विमोचित </translation>
    </message>
</context>
<context>
    <name>DCrumbEdit</name>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="900"/>
        <source>Black</source>
        <translation>श्याम</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="903"/>
        <source>White</source>
        <translation>श्वेत</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="906"/>
        <source>Dark Gray</source>
        <translation>गहरा स्लेटी</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="909"/>
        <source>Gray</source>
        <translation>स्लेटी</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="912"/>
        <source>Light Gray</source>
        <translation>हल्का स्लेटी</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="915"/>
        <source>Red</source>
        <translation>लाल</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="918"/>
        <source>Green</source>
        <translation>हरा</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="921"/>
        <source>Blue</source>
        <translation>नीला</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="924"/>
        <source>Cyan</source>
        <translation>हरिनील</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="927"/>
        <source>Magenta</source>
        <translation>गुलाबी</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="930"/>
        <source>Yellow</source>
        <translation>पीला</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="933"/>
        <source>Dark Red</source>
        <translation>गहरा लाल</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="936"/>
        <source>Dark Green</source>
        <translation>गहरा हरा</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="939"/>
        <source>Dark Blue</source>
        <translation>गहरा नीला</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="942"/>
        <source>Dark Cyan</source>
        <translation>गहरा हरिनील</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="945"/>
        <source>Dark Magenta</source>
        <translation>गहरा गुलाबी</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="948"/>
        <source>Dark Yellow</source>
        <translation>गहरा पीला</translation>
    </message>
</context>
<context>
    <name>DInputDialog</name>
    <message>
        <location filename="../widgets/dinputdialog.cpp" line="42"/>
        <source>Cancel</source>
        <translation>रद्द करें</translation>
    </message>
    <message>
        <location filename="../widgets/dinputdialog.cpp" line="43"/>
        <source>Confirm</source>
        <translation>पुष्टि करें</translation>
    </message>
</context>
<context>
    <name>DKeySequenceEdit</name>
    <message>
        <location filename="../widgets/dkeysequenceedit.cpp" line="85"/>
        <source>Enter a new shortcut</source>
        <translation>नया शॉर्टकट दर्ज़ करें</translation>
    </message>
</context>
<context>
    <name>DLineEdit</name>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="471"/>
        <source>Stop reading</source>
        <translation>पढ़ना बंद करें</translation>
    </message>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="473"/>
        <source>Text to Speech</source>
        <translation>टेक्स्ट से वाणी</translation>
    </message>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="496"/>
        <source>Translate</source>
        <translation>अनुवाद करें</translation>
    </message>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="518"/>
        <source>Speech To Text</source>
        <translation>वाणी से टेक्स्ट</translation>
    </message>
</context>
<context>
    <name>DPrintPreviewDialogPrivate</name>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="232"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1175"/>
        <source>Advanced</source>
        <translation>विस्तृत</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="255"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>रद्द करें</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="256"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1596"/>
        <source>Print</source>
        <comment>button</comment>
        <translation>प्रिंट</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="272"/>
        <source>Basic</source>
        <translation>सामान्य</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="287"/>
        <source>Printer</source>
        <translation>प्रिंटर</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="301"/>
        <source>Copies</source>
        <translation>प्रतिलिपियाँ</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="321"/>
        <source>Page range</source>
        <translation>पृष्ठ सीमा</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="323"/>
        <source>All</source>
        <translation>सभी</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="324"/>
        <source>Current page</source>
        <translation>वर्तमान पृष्ठ</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="325"/>
        <source>Select pages</source>
        <translation>पृष्ठ चयन</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="340"/>
        <source>Orientation</source>
        <translation>अभिविन्यास</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="364"/>
        <source>Portrait</source>
        <translation>लंबवत अभिविन्यास</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="374"/>
        <source>Landscape</source>
        <translation>क्षैतिज अभिविन्यास</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="402"/>
        <source>Pages</source>
        <translation>पृष्ठ</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="412"/>
        <source>Color mode</source>
        <translation>रंगीन मोड</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="414"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1553"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1620"/>
        <source>Color</source>
        <translation>रंग</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="414"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1605"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1620"/>
        <source>Grayscale</source>
        <translation>श्वेत-श्याम</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="425"/>
        <source>Margins</source>
        <translation>सीमांत</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="427"/>
        <source>Narrow (mm)</source>
        <translation>संकीर्ण (मि॰ मी॰)</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="427"/>
        <source>Normal (mm)</source>
        <translation>सामान्य (मि॰ मी॰)</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="427"/>
        <source>Moderate (mm)</source>
        <translation>औसत (मि॰ मी॰)</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="427"/>
        <source>Customize (mm)</source>
        <translation>अनुकूलित (मि॰ मी॰)</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="433"/>
        <source>Top</source>
        <translation>शीर्ष</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="436"/>
        <source>Left</source>
        <translation>बायां</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="439"/>
        <source>Bottom</source>
        <translation>तल</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="442"/>
        <source>Right</source>
        <translation>दायां</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="487"/>
        <source>Scaling</source>
        <translation>अनुमाप परिवर्तन</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="501"/>
        <source>Actual size</source>
        <translation>वास्तविक आकार</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="510"/>
        <source>Scale</source>
        <translation>अनुमाप परिवर्तन</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="541"/>
        <source>Paper</source>
        <translation>पृष्ठ</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="551"/>
        <source>Paper size</source>
        <translation>पृष्ठ आकार</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="564"/>
        <source>Print Layout</source>
        <translation>प्रिंट का अभिन्यास</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="575"/>
        <source>Duplex</source>
        <translation>दोहरा प्रिंट</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="588"/>
        <source>N-up printing</source>
        <translation>एकल पृष्ठ पर एकाधिक पृष्ठ संयोजन</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="590"/>
        <source>2 pages/sheet, 1×2</source>
        <translation>2 पृष्ठ/कागज़, 1x2</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="590"/>
        <source>4 pages/sheet, 2×2</source>
        <translation>4 पृष्ठ/कागज़, 2x2</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="590"/>
        <source>6 pages/sheet, 2×3</source>
        <translation>6 पृष्ठ/कागज़, 2x3</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="590"/>
        <source>9 pages/sheet, 3×3</source>
        <translation>9 पृष्ठ/कागज़, 3x3</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="590"/>
        <source>16 pages/sheet, 4×4</source>
        <translation>16 पृष्ठ/कागज़, 4x4</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="599"/>
        <source>Layout direction</source>
        <translation>अभिन्यास दिशा</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="644"/>
        <source>Page Order</source>
        <translation>पृष्ठ क्रम</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="655"/>
        <source>Collate pages</source>
        <translation>पृष्ठ संयोजन</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="661"/>
        <source>Print pages in order</source>
        <translation>पृष्ठों को क्रमानुसार प्रिंट करें</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="663"/>
        <source>Front to back</source>
        <translation>प्रथम से अंतिम</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="663"/>
        <source>Back to front</source>
        <translation>अंतिम से प्रथम</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="687"/>
        <source>Watermark</source>
        <translation>वॉटरमार्क</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="698"/>
        <source>Add watermark</source>
        <translation>वॉटरमार्क जोड़ें</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="740"/>
        <source>Text watermark</source>
        <translation>शब्द युक्त वॉटरमार्क</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="742"/>
        <source>Confidential</source>
        <translation>गोपनीय</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="742"/>
        <source>Draft</source>
        <translation>प्रारूप</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="742"/>
        <source>Sample</source>
        <translation>नमूना</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="742"/>
        <source>Custom</source>
        <translation>अनुकूलित</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="750"/>
        <source>Input your text</source>
        <translation>शब्द दर्ज करें</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="773"/>
        <source>Picture watermark</source>
        <translation>चित्र युक्त वॉटरमार्क</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="794"/>
        <source>Layout</source>
        <translation>अभिन्यास</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="796"/>
        <source>Tile</source>
        <translation>एकाधिक अनुभाग</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="796"/>
        <source>Center</source>
        <translation>केंद्रित</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="807"/>
        <source>Angle</source>
        <translation>कोण</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="823"/>
        <source>Size</source>
        <translation>आकार</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="844"/>
        <source>Transparency</source>
        <translation>पारदर्शिता</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="901"/>
        <source>Print to PDF</source>
        <translation>PDF रूप में प्रिंट</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="902"/>
        <source>Save as Image</source>
        <translation>चित्र के रूप में संचित करें</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1171"/>
        <source>Collapse</source>
        <translation>संक्षिप्त करें</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1294"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1301"/>
        <source>Flip on short edge</source>
        <translation>क्षैतिज पृष्ठ क्रम</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1297"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1300"/>
        <source>Flip on long edge</source>
        <translation>लंबवत पृष्ठ क्रम</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1397"/>
        <source>Input page numbers please</source>
        <translation>कृपया पृष्ठ संख्या दर्ज करें</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1400"/>
        <source>Maximum page number reached</source>
        <translation>यह पृष्ठ हेतु अधिकतम संख्या है</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1403"/>
        <source>Input English comma please</source>
        <translation>कृपया अल्पविराम दर्ज करें</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1406"/>
        <source>Input page numbers like this: 1,3,5-7,11-15,18,21</source>
        <translation>इस प्रकार अल्पविराम दर्ज करें : 1,3,5-7,11-15,18,21</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1558"/>
        <source>Save</source>
        <comment>button</comment>
        <translation>संचित करें</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="2168"/>
        <source>*.pdf</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1672"/>
        <source>For example, 1,3,5-7,11-15,18,21</source>
        <translation>उदाहरण, 1,3,5-7,11-15,18,21</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="2168"/>
        <source>Save as PDF</source>
        <translation>PDF रूप में संचित</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="2207"/>
        <source>Save as image</source>
        <translation>चित्र के रूप में संचित</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="2209"/>
        <source>Images</source>
        <translation>चित्र</translation>
    </message>
</context>
<context>
    <name>DPrintPreviewWidget</name>
    <message>
        <location filename="../widgets/dprintpreviewwidget.cpp" line="1590"/>
        <location filename="../widgets/dprintpreviewwidget.cpp" line="1593"/>
        <source>Confidential</source>
        <translation>गोपनीय</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewwidget.cpp" line="1608"/>
        <location filename="../widgets/dprintpreviewwidget.cpp" line="1611"/>
        <source>Draft</source>
        <translation>प्रारूप</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewwidget.cpp" line="1626"/>
        <location filename="../widgets/dprintpreviewwidget.cpp" line="1629"/>
        <source>Sample</source>
        <translation>नमूना</translation>
    </message>
</context>
<context>
    <name>DSearchEdit</name>
    <message>
        <location filename="../widgets/dsearchedit.cpp" line="291"/>
        <source>Search</source>
        <translation>खोजें</translation>
    </message>
</context>
<context>
    <name>DSettingsDialog</name>
    <message>
        <location filename="../widgets/dsettingswidgetfactory.cpp" line="78"/>
        <source>Cancel</source>
        <translation>रद्द करें</translation>
    </message>
    <message>
        <location filename="../widgets/dsettingswidgetfactory.cpp" line="79"/>
        <source>Replace</source>
        <translation>से बदलें</translation>
    </message>
    <message>
        <location filename="../widgets/dsettingswidgetfactory.cpp" line="81"/>
        <source>This shortcut conflicts with %1, click on Add to make this shortcut effective immediately</source>
        <translation>यह शॉर्टकट %1 के विरुद्ध है, जोड़ें पर क्लिक कर इसे तुरंत प्रभाव से लागू करें</translation>
    </message>
</context>
<context>
    <name>DShortcutEdit</name>
    <message>
        <location filename="../widgets/dshortcutedit.cpp" line="31"/>
        <source>Please input a new shortcut</source>
        <translation>कृपया नया इनपुट करें</translation>
    </message>
    <message>
        <location filename="../widgets/dshortcutedit.cpp" line="102"/>
        <source>None</source>
        <translation>कुछ नहीं</translation>
    </message>
</context>
<context>
    <name>DTextEdit</name>
    <message>
        <location filename="../widgets/dtextedit.cpp" line="171"/>
        <source>Stop reading</source>
        <translation>पढ़ना बंद करें</translation>
    </message>
    <message>
        <location filename="../widgets/dtextedit.cpp" line="173"/>
        <source>Text to Speech</source>
        <translation>टेक्स्ट से वाणी</translation>
    </message>
    <message>
        <location filename="../widgets/dtextedit.cpp" line="196"/>
        <source>Translate</source>
        <translation>अनुवाद करें</translation>
    </message>
    <message>
        <location filename="../widgets/dtextedit.cpp" line="218"/>
        <source>Speech To Text</source>
        <translation>वाणी से टेक्स्ट</translation>
    </message>
</context>
<context>
    <name>PickColorWidget</name>
    <message>
        <location filename="../widgets/dprintpickcolorwidget.cpp" line="109"/>
        <source>Color</source>
        <translation>रंग</translation>
    </message>
</context>
<context>
    <name>QLineEdit</name>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="454"/>
        <source>Select All</source>
        <translation>सारा चयनित</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../widgets/dsimplelistview.cpp" line="1334"/>
        <source>No search result</source>
        <translation>खोज का परिणाम नहीं मिला</translation>
    </message>
    <message>
        <location filename="../widgets/private/settings/content.cpp" line="331"/>
        <source>Restore Defaults</source>
        <translation>मूल स्वरूप पुनः स्थापित करें</translation>
    </message>
</context>
<context>
    <name>QWidgetTextControl</name>
    <message>
        <location filename="../widgets/dtextedit.cpp" line="163"/>
        <source>Select All</source>
        <translation>सारा चयनित</translation>
    </message>
</context>
<context>
    <name>ShortcutEdit</name>
    <message>
        <location filename="../widgets/private/settings/shortcutedit.cpp" line="117"/>
        <source>Please enter a new shortcut</source>
        <translation>कृपया नया शॉर्टकट दर्ज़ करें</translation>
    </message>
</context>
<context>
    <name>TitleBarMenu</name>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="527"/>
        <source>Theme</source>
        <translation>थीम</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="529"/>
        <source>Light Theme</source>
        <translation>हल्की थीम</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="530"/>
        <source>Dark Theme</source>
        <translation>गहरी थीम</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="531"/>
        <source>System Theme</source>
        <translation>सिस्टम थीम</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="555"/>
        <source>Help</source>
        <translation>मदद</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="563"/>
        <source>About</source>
        <translation>बारे में</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="570"/>
        <source>Exit</source>
        <translation>बंद करें</translation>
    </message>
</context>
</TS>